==> newsflash-7.x-2.0.tar.gz: newsflash/template.php <==
<?php
function get_newsflash_style() 
{
  $style = theme_get_setting('newsflash_style');
  if (!$style)
  {
    $style = 'blue';
  }
  if (isset($_COOKIE["newsflashstyle"])) 
  {
    $style = $_COOKIE["newsflashstyle"];
  }
  return $style;
}

$style = get_newsflash_style();
drupal_add_css(path_to_theme() . '/style.css'); //is not settet in info file because it's loades to late
drupal_add_css(path_to_theme() . '/css/' . $style . '.css');
if (theme_get_setting('newsflash_suckerfish')) {
  drupal_add_css(path_to_theme() . '/css/suckerfish_'  . $style . '.css');
} else {
  drupal_add_css(path_to_theme() . '/css/nosuckerfish.css');
}

if (theme_get_setting('newsflash_uselocalcontent'))
{
/**	$local_content = path_to_theme() . '/' . theme_get_setting('newsflash_localcontentfile'); */
  $local_content =  theme_get_setting('newsflash_localcontentfile');
  if (file_exists($local_content)) 
  {
    drupal_add_css($local_content);
  }
}

function newsflash_preprocess_html(&$vars) 
{  

  drupal_add_css
  (
    path_to_theme() . '/css/ie.css', 
    array
    (
      'group' => CSS_THEME, 
      'browsers' => array
      (
      'IE' => 'IE', 
      '!IE' => FALSE
      ), 
    'preprocess' => FALSE
    )
  );
}


if (theme_get_setting('newsflash_iepngfix')) 
{
  drupal_add_js(path_to_theme() . '/js/jquery.pngFix.js');
}
function newsflash_preprocess_block(&$variables) {
  // In the header region visually hide block titles.
  if (theme_get_setting('newsflash_suckerfish') && $variables['block']->region == 'suckerfish') {
    $variables['title_attributes_array']['class'][] = 'element-invisible';
  }
  if ($variables['block']->region == 'header') {
    $variables['title_attributes_array']['class'][] = 'element-invisible';
  }
    $variables['title_attributes_array']['class'][] = 'title';
}

==> newsflash-7.x-2.1.tar.gz: newsflash/template.php <==
<?php
// get setted color style and save it in a cookie
function get_newsflash_style() 
{
  $style = theme_get_setting('newsflash_style');
  if (!$style)
  {
    $style = 'blue';
  }
  if (isset($_COOKIE["newsflashstyle"])) 
  {
    $style = $_COOKIE["newsflashstyle"];
  }
  return $style;
}
// set the color style themes
$style = get_newsflash_style();
drupal_add_css(path_to_theme() . '/style.css'); //is not settet in info file because it's loades to late
drupal_add_css(path_to_theme() . '/css/' . $style . '.css');
if (theme_get_setting('newsflash_suckerfish')) {
  drupal_add_css(path_to_theme() . '/css/suckerfish_'  . $style . '.css');
} else {
  drupal_add_css(path_to_theme() . '/css/nosuckerfish.css');
}

// set for custome css
if (theme_get_setting('newsflash_uselocalcontent'))
{
/**	$local_content = path_to_theme() . '/' . theme_get_setting('newsflash_localcontentfile'); */
  $local_content =  theme_get_setting('newsflash_localcontentfile');
  if (file_exists($local_content)) 
  {
    drupal_add_css($local_content);
  }
}

// add ie css fixin some px settings in css
function newsflash_preprocess_html(&$vars) 
{  
  drupal_add_css
  (
    path_to_theme() . '/css/ie.css', 
    array
    (
      'group' => CSS_THEME, 
      'browsers' => array
      (
      'IE' => 'IE', 
      '!IE' => FALSE
      ), 
    'preprocess' => FALSE
    )
  );
}

//ie png fix
if (theme_get_setting('newsflash_iepngfix')) 
{
  drupal_add_js(path_to_theme() . '/js/jquery.pngFix.js');
}

// in sukerfishmenu, searchbox. and header region visually hide block titles.
function newsflash_preprocess_block(&$variables) {
  // In the suckerfishmenu region visually hide block titles if use suckerfish enabled.
  if (theme_get_setting('newsflash_suckerfish') && $variables['block']->region == 'suckerfish') {
    $variables['title_attributes_array']['class'][] = 'element-invisible';
  }
  if ($variables['block']->region == 'header') {
    $variables['title_attributes_array']['class'][] = 'element-invisible';
  }
    //adds in blocks title the class .title
    $variables['title_attributes_array']['class'][] = 'title';
}
